package com.activities;

import android.app.Activity;
import android.content.ClipData;
import android.content.ClipboardManager;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.*;
import com.data.ChatAdapter;
import com.data.ChatArrayList;
import com.data.ChatMessage;
import com.data.User;

import java.util.ArrayList;
import java.util.Random;

/**
 * Created with IntelliJ IDEA.
 * User: Wolfram
 * Date: 14.10.13
 * Time: 13:04
 */
public class Activity_Chat extends Activity {
    private ListView messageHistory;
    private ArrayList<ChatMessage> messages; // the stored messages and timestamps
    private ChatAdapter messagesAdapter; // to automatically update the ListView with onDataSetChanged
    private User you, notyou;
    private ImageButton b;
    private Animation send_anim;

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.layout_chat);
        b = (ImageButton) findViewById(R.id.send);
        send_anim = AnimationUtils.loadAnimation(this, R.anim.send_animation);
        you = new User("Wolfram");
        notyou = new User("Gary");
        messageHistory = (ListView) findViewById(R.id.view_chat);
        messages = new ChatArrayList();
        messagesAdapter = new ChatAdapter(this, messages, you);
        messageHistory.setAdapter(messagesAdapter); // set the data of the list
        registerForContextMenu(messageHistory); // register all list items for the context menu
        loadMessages();
    }

    /**
     * Handles the ContextMenu actions.
     */
    @Override
    public boolean onContextItemSelected(MenuItem item) {
        AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) item.getMenuInfo(); // the item whose context menu was called
        switch (item.getItemId()) {
            case R.id.option_deleteMessage:
                deleteMessage(info.position); // delete the selected message
                return true;
            case R.id.option_copyText:
                copyText(info.position);
            default:
                return super.onContextItemSelected(item);
        }
    }

    /**
     * Deletes the given Message.
     *
     * @param messageIndex the index of the message in the list
     */
    private void deleteMessage(int messageIndex) {
        /* todo: maybe add animation */
        messages.remove(messageIndex);
        messagesAdapter.notifyDataSetChanged();
    }

    /**
     * Loads all saved Messages into the Messages-list.
     */
    private void loadMessages() {
        /* todo: replace test loading with actual messages from User-objects */
        /* todo: maybe add the custom views (like: delete) */
        Random r = new Random();
        String alphabet = "abcdefghijklmonpqestuvwxyzöüä";
        for (int j = 0; j < 100; j++) {
            int saize = (int) (Math.random() * 100 + 1);
            String print = "";
            ChatMessage dummy = null;
            for (int i = 0; i < saize; i++) {
                print += (alphabet.charAt(r.nextInt(alphabet.length())));
                dummy = (i % 2 == 0) ? new ChatMessage(you, notyou, print) : new ChatMessage(notyou, you, print);
            }
            testSendMessage(dummy);
        }
    }

    /**
     * Creates the ContextMenu of an individual List item
     */
    @Override
    public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo) {
        super.onCreateContextMenu(menu, v, menuInfo);
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.menu_message, menu);
    }

    /**
     * Checks if the Message is empty, if so shows a Toast, else sends a Message via sendMessage() and animates the button
     *
     * @param v ButtonView
     */
    public void sendMessagePressed(View v) {
        EditText text = (EditText) findViewById(R.id.eingabe);
        String tmp = text.getText().toString().trim();
        if (tmp.equals("")) {
            Toast.makeText(this, "No empty Messages", Toast.LENGTH_SHORT).show();
        } else {
            b.startAnimation(send_anim);
            sendMessage(tmp);
            text.setText("");
        }
    }

    /**
     * Adds a Message to local messages, updates the View and scrolls to bottom of the list.
     *
     * @param text New Messages Text
     */
    public void sendMessage(String text) {
        messages.add(new ChatMessage(you, notyou, text));
        messagesAdapter.notifyDataSetChanged();
        messageHistory.setSelection(messagesAdapter.getCount() - 1);
    }

    /**
     * Used for Testing only, user has no access to this
     * Sends a message with defined ChatMessage
     *
     * @param newChatMessage
     */
    public void testSendMessage(ChatMessage newChatMessage) {
        messages.add(newChatMessage);
        messagesAdapter.notifyDataSetChanged();
        messageHistory.setSelection(messagesAdapter.getCount() - 1);
    }

    /**
     * Used to copy a Messages Text
     *
     * @param pos
     */
    public void copyText(int pos) {
        ClipboardManager clipboard = (ClipboardManager) getSystemService(CLIPBOARD_SERVICE);
        ClipData clip = ClipData.newPlainText("S/Chat", messages.get(pos).getMessage());
        clipboard.setPrimaryClip(clip);
    }
}